from distutils.core import setup
setup(
  name = 'transfermarkt',         # How you named your package folder (MyLib)
  packages = ['transfermarkt'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A package to query transfermarkt, mainly aimed at statistics',   # Give a short description about your library
  author = 'Omer Ben David',                   # Type in your name
  author_email = 'omerbendavid21@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/omerbd21/transfermarkt',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/omerbd21/transfermarkt/archive/refs/tags/test.tar.gz',    # I explain this later on
  keywords = ['transfermarkt', 'ML', 'Statistics', 'BeautifulSoup', 'AI', 'Football', 'Soccer'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'beautifulsoup4',
          'bs4',
          'certifi',
          'charset-normalizer',
          'idna',
          'requests',
          'soupsieve',
          'urllib3',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.9',
  ],
)